@@ -508,7 +508,7 @@ def main():
     global sig_dwl
     sig_dwl = args.sigdwl
 
-    catchable_sigs = set(signal.Signals) - {signal.SIGKILL, signal.SIGSTOP}
+    catchable_sigs = set(signal.Signals) - {signal.SIGKILL, signal.SIGSTOP, signal.SIGCHLD}
     for sig in catchable_sigs:
         try:
             signal.signal(sig, signal_handler)
