@@ -499,8 +499,11 @@ def list_sink_inputs():
     """
     Thanks to @fm16191 for https://github.com/fm16191/pactl-json-parser
     """
-    p = subprocess.run("pactl list sink-inputs".split(), capture_output=True)
-    result = p.stdout.decode()
+    # This used to return localized output, returning unexpected values #327
+    # p = subprocess.run("pactl list sink-inputs".split(), capture_output=True)
+    # result = p.stdout.decode()
+
+    result = cmd2string("pactl list sink-inputs")
 
     # Syntax fix
     result = result.replace(u"\xa0", " ")  # Broken encoding for spaces
@@ -922,13 +925,17 @@ def h_modules_get_all():
 
 
 def cmd_through_compositor(cmd):
+    cmd = cmd.replace("\"", "'")
     cs_file = os.path.join(get_config_dir(), "common-settings.json")
     common_settings = load_json(cs_file)
     if "run-through-compositor" not in common_settings or common_settings["run-through-compositor"] :
         if os.getenv("SWAYSOCK"):
-            cmd = f'swaymsg exec "{cmd.replace("\"", "'")}"'
+            if os.getenv("XDG_SESSION_DESKTOP") and "miracle-wm" in os.getenv("XDG_SESSION_DESKTOP"):
+                cmd = f'miraclemsg exec "{cmd}"'
+            else:
+                cmd = f'swaymsg exec "{cmd}"'
         elif os.getenv("HYPRLAND_INSTANCE_SIGNATURE"):
-            cmd = f'hyprctl dispatch exec "{cmd.replace("\"", "'")}"'
+            cmd = f'hyprctl dispatch exec "{cmd}"'
     return cmd
 
 
